# FunctionLogger subpackage developing notes

These notes are used for keeping track of ToDos and porting information.

## Matlab references
- Everything in: [funlogger_vbmc.m](https://github.com/acerbilab/vbmc/blob/master/misc/funlogger_vbmc.m)
